@@ -1,14 +1,20 @@
-# $Id: Matrices.pm,v 1.21 2005/09/29 20:31:17 rvosa Exp $
+# $Id: Matrices.pm,v 1.25 2006/03/14 12:01:56 rvosa Exp $
 # Subversion: $Rev: 186 $
 package Bio::Phylo::Matrices;
 use strict;
-use warnings;
-use base 'Bio::Phylo::Listable';
-use Bio::Phylo::CONSTANT qw(_NONE_ _MATRICES_);
+use Bio::Phylo::Listable;
+use Bio::Phylo::Util::IDPool;
+use Bio::Phylo::Util::CONSTANT qw(_NONE_ _MATRICES_);
 
 # One line so MakeMaker sees it.
 use Bio::Phylo; our $VERSION = $Bio::Phylo::VERSION;
 
+# classic @ISA manipulation, not using 'base'
+use vars qw($VERSION @ISA);
+@ISA = qw(Bio::Phylo::Listable);
+
+{
+
 =head1 NAME
 
 Bio::Phylo::Matrices - Holds a set of matrix objects.
@@ -46,30 +52,39 @@ are available to apply to a set of matrices.
 
 =cut
 
-sub new {
-    my $class = shift;
-    my $self = fields::new($class);
-    $self->SUPER::new(@_);
-    if (@_) {
-        my %opts;
-        eval { %opts = @_; };
-        if ($@) {
-            Bio::Phylo::Exceptions::OddHash->throw(
-                error => $@
-            );
-        }
-        while ( my ( $key, $value ) = each %opts ) {
-            my $localkey = uc substr $key, 1;
-            eval { $self->{$localkey} = $value; };
-            if ($@) {
-                Bio::Phylo::Exceptions::BadArgs->throw(
-                    error => "invalid field specified: $key ($localkey)"
-                );
-            }
-        }
+    sub new {
+        my ( $class, $self ) = shift;
+        $self = __PACKAGE__->SUPER::new(@_);
+        bless $self, __PACKAGE__;
+        return $self;
     }
-    return $self;
-}
+    
+=back
+
+=head2 DESTRUCTOR
+
+=over
+
+=item DESTROY()
+
+ Type    : Destructor
+ Title   : DESTROY
+ Usage   : $phylo->DESTROY
+ Function: Destroys Phylo object
+ Alias   :
+ Returns : TRUE
+ Args    : none
+ Comments: You don't really need this, 
+           it is called automatically when
+           the object goes out of scope.
+
+=cut
+
+    sub DESTROY {
+        my $self = shift;
+        $self->SUPER::DESTROY;
+        return 1;
+    }    
 
 =begin comment
 
@@ -84,7 +99,7 @@ sub new {
 
 =cut
 
-sub _container { _NONE_ }
+    sub _container { _NONE_ }
 
 =begin comment
 
@@ -99,7 +114,7 @@ sub _container { _NONE_ }
 
 =cut
 
-sub _type { _MATRICES_ }
+    sub _type { _MATRICES_ }
 
 =back
 
@@ -134,7 +149,7 @@ and then you'll automatically be notified of progress on your bug as I make
 changes. Be sure to include the following in your request or comment, so that
 I know what version you're using:
 
-$Id: Matrices.pm,v 1.21 2005/09/29 20:31:17 rvosa Exp $
+$Id: Matrices.pm,v 1.25 2006/03/14 12:01:56 rvosa Exp $
 
 =head1 AUTHOR
 
@@ -163,4 +178,6 @@ modify it under the same terms as Perl itself.
 
 =cut
 
+}
+
 1;
